Documentation
¶
Index ¶
Constants ¶
const ( // MoveNone represents the flag that the bird has no movement MoveNone = 0x00 // MoveLeft represents the flag to move the bird to the left MoveLeft = 0x01 // MoveRight represents the flag to move the bird to the right MoveRight = 0x02 // MoveUp represents the flag to move the bird to the up MoveUp = 0x04 // MoveDown represents the flag to move the bird to the down MoveDown = 0x08 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreditsSystem ¶
type CreditsSystem struct {
Name string
EntityManager *entity.Manager
InputManager *input.Manager
RenderSystem *system.RenderSystem
SceneManager *macaw.SceneManager
}
CreditsSystem is the struct that contains the controllable stick
func (*CreditsSystem) SetSceneManager ¶
func (m *CreditsSystem) SetSceneManager(sm *macaw.SceneManager)
SetSceneManager sets the scene manager in the system
type MenuSystem ¶
type MenuSystem struct {
Name string
EntityManager *entity.Manager
InputManager *input.Manager
RenderSystem *system.RenderSystem
SceneManager *macaw.SceneManager
// contains filtered or unexported fields
}
MenuSystem is the struct that contains the controllable stick
func (*MenuSystem) SetSceneManager ¶
func (m *MenuSystem) SetSceneManager(sm *macaw.SceneManager)
SetSceneManager sets the scene manager in the system
type PlayerSystem ¶
type PlayerSystem struct {
EntityManager *entity.Manager
Name string
InputManager *input.Manager
CollisionSystem *system.CollisionSystem
RenderSystem *system.RenderSystem
SceneManager *macaw.SceneManager
// contains filtered or unexported fields
}
PlayerSystem is the struct that contains the controllable stick
func (*PlayerSystem) SetSceneManager ¶
func (p *PlayerSystem) SetSceneManager(sm *macaw.SceneManager)
SetSceneManager sets the scene manager in the system
type ScrollSystem ¶
ScrollSystem is the struct that contains the controllable stick
func (*ScrollSystem) Init ¶
func (s *ScrollSystem) Init()
Init initializes the render system using the current window
type SpawnSystem ¶
type SpawnSystem struct {
EntityManager *entity.Manager
Name string
RenderSystem *system.RenderSystem
CollisionSystem *system.CollisionSystem
Spritesheet *entity.Spritesheet
Sprites map[string]entity.RenderComponent
// contains filtered or unexported fields
}
SpawnSystem is the struct that contains the controllable stick
Click to show internal directories.
Click to hide internal directories.